@@ -1,6 +1,7 @@
 import asyncio
 import logging
 from typing import Dict
+from typing import List
 from typing import Set
 
 from senor_octopus.graph import Source
@@ -14,19 +15,27 @@ SLEEP_TIME = 5
 class Scheduler:
     def __init__(self, dag: Set[Source]):
         self.dag = dag
+        self.tasks: List[asyncio.Task] = []
+        self.cancelled = False
 
     async def run(self) -> None:
-        nodes = {node for node in self.dag if node.schedule}
-        if not nodes:
-            _logger.info("Nothing to schedule")
+        if not self.dag:
+            _logger.info("Nothing to run")
             return
 
         _logger.info("Starting scheduler")
         loop = asyncio.get_event_loop()
 
+        event_nodes = {node for node in self.dag if not node.schedule}
+        for node in event_nodes:
+            _logger.debug("Starting %s", node.name)
+            task = asyncio.create_task(node.run())
+            self.tasks.append(task)
+
+        schedule_nodes = {node for node in self.dag if node.schedule}
         schedules: Dict[str, float] = {}
-        while True:
-            for node in nodes:
+        while not self.cancelled:
+            for node in schedule_nodes:
                 now = loop.time()
                 delay = node.schedule.next(default_utc=False)
                 when = now + delay
@@ -36,8 +45,14 @@ class Scheduler:
                     schedules[node.name] = when
                 elif schedules[node.name] <= now:
                     _logger.info(f"Running {node.name}")
-                    await node.run()
+                    task = asyncio.create_task(node.run())
+                    self.tasks.append(task)
                     del schedules[node.name]
 
             _logger.debug(f"Sleeping for {SLEEP_TIME} seconds")
             await asyncio.sleep(SLEEP_TIME)
+
+    def cancel(self) -> None:
+        for task in self.tasks:
+            task.cancel()
+        self.cancelled = True
